<?php

namespace Drupal\big_datatable\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\big_datatable\Entity\BigDataTable;

/**
 * Returns responses for Big Tables routes.
 */
class BigDataTableController extends ControllerBase {

  /**
   * Enables a BigDataTable object.
   *
   * @param \Drupal\big_datatable\Entity\BigDataTable $big_datatable
   *   The BigDataTable object for view.
   */
  public function view(BigDataTable $big_datatable) {
    $build = [];
    $html_file_name = $big_datatable->id();
    $build['custom_title'] = [
      '#markup' => '<h2>' . $big_datatable->getTitle() . '</h2>',
    ];
    $build['description'] = [
      '#markup' => '<div class="big-table-description">' . $big_datatable->getBody()['value'] . '</div>',
    ];
    $html_file_path = 'public://big_data_tables/' . $html_file_name . '.html';
    if ($this->fileExists($html_file_path)) {
      $html_content = $this->getFileContents($html_file_path);
      $build['table'] = [
        '#markup' => $html_content,
      ];
    }
    else {
      $build['table'] = [
        '#markup' => $this->t('The HTML file does not exist.'),
      ];
    }
    $build['#attached']['library'][] = 'big_datatable/big_datatable_styling';
    return $build;
  }

  /**
   * Enable a BigDataTable object.
   *
   * @param \Drupal\big_datatable\Entity\BigDataTable $big_datatable
   *   The BigDataTable object for title.
   */
  public function title(BigDataTable $big_datatable) {
    return $big_datatable->label();
  }

  /**
   * Check if a file exists.
   *
   * @param string $html_file_path
   *   The path of the HTML file.
   *
   * @return bool
   *   TRUE if the file exists, FALSE otherwise.
   */
  public function fileExists($html_file_path) {
    return file_exists($html_file_path);
  }

  /**
   * Get the contents of a file.
   *
   * @param string $html_file_path
   *   The path of the HTML file.
   *
   * @return string|false
   *   The file contents or FALSE on failure.
   */
  public function getFileContents($html_file_path) {
    return file_get_contents($html_file_path);
  }

}
