<?php

namespace Drupal\big_datatable\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\big_datatable\BigDataTableInterface;

/**
 * Defines the big data table entity type.
 *
 * @ConfigEntityType(
 *   id = "big_datatable",
 *   label = @Translation("Big Data Table"),
 *   label_collection = @Translation("Big Data Tables"),
 *   label_singular = @Translation("big data table"),
 *   label_plural = @Translation("big data tables"),
 *   label_count = @PluralTranslation(
 *     singular = "@count big data table",
 *     plural = "@count big data tables",
 *   ),
 *   handlers = {
 *     "list_builder" = "Drupal\big_datatable\BigTableListBuilder",
 *     "form" = {
 *       "add" = "Drupal\big_datatable\Form\BigDataTableForm",
 *       "edit" = "Drupal\big_datatable\Form\BigDataTableForm",
 *       "delete" = "Drupal\Core\Entity\EntityDeleteForm"
 *     }
 *   },
 *   config_prefix = "big_datatable",
 *   admin_permission = "administer big_datatable",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "name",
 *   },
 *   config_export = {
 *     "id",
 *     "name",
 *     "title",
 *     "body",
 *     "bigdata_file",
 *     "url",
 *   },
 *   links = {
 *     "collection" = "/admin/system/big-data-table",
 *     "add-form" = "/admin/system/big-data-table/add",
 *     "edit-form" = "/admin/system/big-data-table/{big_datatable}",
 *     "delete-form" = "/admin/system/big-data-table/{big_datatable}/delete",
 *     "view" = "/admin/config/system/big_datatable/{big_datatable}",
 *   }
 * )
 */
class BigDataTable extends ConfigEntityBase implements BigDataTableInterface, \JsonSerializable {

  /**
   * The ID of the tables.
   *
   * @var string
   */
  protected $id;

  /**
   * The table label.
   *
   * @var string
   */
  protected $name;

  /**
   * The title of the table.
   *
   * @var string
   */
  protected $title;

  /**
   * The formatted text of the table.
   *
   * @var array
   */
  protected $body;

  /**
   * The fid of CSV file.
   *
   * @var int
   */
  protected $bigdata_file;

  /**
   * {@inheritdoc}
   */
  public function getTitle() {
    return $this->title;
  }

  /**
   * {@inheritdoc}
   */
  public function getBody() {
    return $this->body;
  }

  /**
   * {@inheritdoc}
   */
  public function getBigdataFile() {
    return $this->bigdata_file;
  }

  /**
   * {@inheritdoc}
   */
  public function setTitle($title) {
    $this->title = $title;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function setBody($body) {
    $this->body = $body;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function setBigdataFile($bigdata_file) {
    $this->bigdata_file = $bigdata_file[0];
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function jsonSerialize(): mixed {
    $body = isset($this->body['value']) ? check_markup(
      $this->body['value'],
      $this->body['format'] ?? NULL
    ) : '';

    return [
      'id' => $this->id(),
      'name' => $this->label(),
      'title' => $this->title,
      'body' => $body,
      'bigdata_file' => $this->bigdata_file,
    ];
  }

}
