<?php

namespace Drupal\big_datatable\Tests\Unit;

use Drupal\Tests\UnitTestCase;
use Drupal\big_datatable\Controller\BigDataTableController;
use Drupal\big_datatable\Entity\BigDataTable;

/**
 * Unit tests for the BigDataTableController class.
 */
class BigDataTableControllerTest extends UnitTestCase {
  /**
   * The controller instance being tested.
   *
   * @var \Drupal\big_datatable\Controller\BigDataTableController
   */
  protected $controller;

  /**
   * A mock of the BigDataTable entity.
   *
   * @var \Drupal\big_datatable\Entity\BigDataTable|\PHPUnit\Framework\MockObject\MockObject
   */
  protected $bigDataTableMock;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    $this->controller = new BigDataTableController();
    $this->bigDataTableMock = $this->createMock(BigDataTable::class);
  }

  /**
   * Tests the title method.
   */
  public function testTitle() {
    $this->bigDataTableMock->method('label')->willReturn('Test Title');
    $title = $this->controller->title($this->bigDataTableMock);
    $this->assertNotEmpty($title, 'Title should not be empty');
    $this->assertEquals('Test Title', $title, 'Title should match the expected value');
  }

  /**
   * Tests the view method.
   */
  public function testView() {
    $this->bigDataTableMock->expects($this->once())
      ->method('id')
      ->willReturn('test_id');

    $this->bigDataTableMock->expects($this->once())
      ->method('getTitle')
      ->willReturn('Test Title');

    $this->bigDataTableMock->expects($this->once())
      ->method('getBody')
      ->willReturn(['value' => 'Test Body']);

    $this->controller = $this->getMockBuilder('Drupal\big_datatable\Controller\BigDataTableController')
      ->disableOriginalConstructor()
      ->onlyMethods(['fileExists', 'getFileContents'])
      ->getMock();

    $this->controller->expects($this->once())
      ->method('fileExists')
      ->with($this->equalTo('public://big_data_tables/test_id.html'))
      ->willReturn(TRUE);

    $this->controller->expects($this->once())
      ->method('getFileContents')
      ->willReturn('<html><body>Test Table</body></html>');

    $result = $this->controller->view($this->bigDataTableMock);
    unset($result['#attached']);
    $expected = [
      'custom_title' => [
        '#markup' => '<h2>Test Title</h2>',
      ],
      'description' => [
        '#markup' => '<div class="big-table-description">Test Body</div>',
      ],
      'table' => [
        '#markup' => '<html><body>Test Table</body></html>',
      ],
    ];

    $this->assertEquals($expected, $result, 'View output should match the expected array');
  }

}
